import type { ConsentType, ServiceFullInfo, ServiceId, ServiceInfo, ServiceInfoFromLocalStorage } from './types.js';
export declare const IS_BROWSER: boolean;
/**
 * Programmatic way to show First Layer.
 * @see https://docs.usercentrics.com/#/cmp-v2-ui-api?id=showfirstlayer
 *
 * @example showFirstLayer()
 */
export declare const showFirstLayer: () => void;
/**
 * Programmatic way to show Second Layer. If a service/vendor Id value is passed,
 * Second Layer will open the right tab, scroll to the given service/vendor entry and expand it.
 * If no Id is passed, Second Layer will be shown without srcolling to any specific service/vendor.
 *
 * @see https://docs.usercentrics.com/#/cmp-v2-ui-api?id=showsecondlayer
 *
 * @example showSecondLayer('my-service-id')
 * @example showSecondLayer()
 */
export declare const showSecondLayer: (serviceId?: ServiceId) => void;
/**
 * A method to get array of all services with their basic information
 * @see https://docs.usercentrics.com/#/cmp-v2-ui-api?id=getservicesbaseinfo
 *
 * @example
 * const services = getServicesBaseInfo()
 * const myService = services.find((service) => service.id === 'my-service-id')
 */
export declare const getServicesBaseInfo: () => ServiceInfo[];
/**
 * A method to get array of all services from local storage
 *
 * @example
 * const services = getServicesFromLocalStorage()
 * const myService = services.find((service) => service.id === 'my-service-id')
 */
export declare const getServicesFromLocalStorage: () => ServiceInfoFromLocalStorage[];
/**
 * A method to check if user has interacted with the consent prompt and given consent information.
 *
 * @example
 * const userInteracted = hasUserInteracted()
 * if (userInteracted) {
 *  actionRequiredConsentInfoGiven()
 * }
 */
export declare const hasUserInteracted: () => boolean;
/**
 * A method to get array of all services with their full information.
 * An extra api request will be made, therefore the return represents
 * the eventual completion (or failure) of an asynchronous operation
 * and its returning value.
 *
 * @see https://docs.usercentrics.com/#/cmp-v2-ui-api?id=getservicesfullinfo
 *
 * @example
 * const services = await getServicesFullInfo()
 * const myService = services.find((service) => service.id === 'my-service-id')
 */
export declare const getServicesFullInfo: () => Promise<ServiceFullInfo[]>;
/**
 * Returns true if Usercentrics service has been given consent
 *
 * @example
 * const services = getServicesBaseInfo()
 * const myService = services.find((service) => service.id === 'my-service-id')
 * const hasConsent = hasServiceConsent(myService)
 *
 * if (hasConsent) {
 *   loadMyService()
 * }
 */
export declare const hasServiceConsent: (service: ServiceInfo | null) => boolean;
/**
 * A method for accepting a single service.
 * @see https://docs.usercentrics.com/#/cmp-v2-ui-api?id=acceptservice
 */
export declare const acceptService: (serviceId: ServiceId, consentType?: ConsentType) => Promise<void>;
